# Changes

## 2022.8.7

* Bumped dependencies for development and test
* Moved from no docs to mkdocs
* Added documentation at https://codes.dilettant.life/docs/mapology
* Moved tracker to https://todo.sr.ht/~sthagen/mapology
* Moved normative source repo to https://git.sr.ht/~sthagen/mapology
* Added test coverage documentation at https://codes.dilettant.life/coverage/mapology
 
## Older

### 2022.4.7

* Fixed resource packaging (again)
* Still work in progress (WIP)

### 2022.4.6

* Extended resource packaging adding base pages to the tree
* Added service command tree that calls icao, prefix, and index in sequence
* Documented the use of some env vars and the need to export these
* Still work in progress (WIP)

### 2022.4.5

* Fixed resource packaging
* Still work in progress (WIP)

### 2022.4.4

* Fixes and refactoring
* Added eject command for templates
* Fixed country naming in prefix pages
* Fixed library path handling
* Added public API for library path

### 2022.4.3

* Fixes and refactoring
* Knowing the environment variable names expected one can parametrize the templates
* ... and provide local templates
* Still work in progress (WIP)

### 2022.3.31

* Homegrown CLI API offering all tools
* Implemented a little razor
* Accelerated ICAO processing by a factor of ten by splitting the databases per regions
* Removed app dependencies from spike
* Bumped development and test dependencies
* Removed dummy tests and created initial CLI tests - 35% coverage - yeah ... well, ahem
* Still work in progress (WIP)

### 2021.5.15 (v0.0.1)

* Initial release to PyPI
* Still work in progress (WIP)
